@@ -79,7 +79,8 @@ KNOWN_MIME_TYPES = {
     'application/x-sh':       ['sh'],
     'application/x-csh':      ['csh'],
     'application/x-troff':    ['nroff', 'roff', 'troff'],
-    'application/x-troff':    ['nroff', 'roff', 'troff'],
+    'application/x-yaml':     ['yml', 'yaml'],
+    
     'application/rss+xml':    ['rss'],
     
     'image/x-icon':           ['ico'],
@@ -349,7 +350,7 @@ class Mimeview(Component):
             for k, n, e, im, om, q in converter.get_supported_conversions():
                 if im == mimetype and q > 0:
                     converters.append((k, n, e, im, om, q, converter))
-        converters = sorted(converters, key=lambda i: i[-1], reverse=True)
+        converters = sorted(converters, key=lambda i: i[-2], reverse=True)
         return converters
 
     def convert_content(self, req, mimetype, content, key, filename=None,
@@ -604,8 +605,8 @@ class Mimeview(Component):
                                                          content, selector)
         req.send_response(200)
         req.send_header('Content-Type', output_type)
-        req.send_header('Content-Disposition', 'filename=%s.%s' % (filename,
-                                                                   ext))
+        req.send_header('Content-Disposition', 'attachment; filename=%s.%s' % 
+                        (filename, ext))
         req.end_headers()
         req.write(content)
         raise RequestDone        
