@@ -243,7 +243,7 @@ class RoadmapModule(Component):
             if milestone.has_key('due'):
                 write_prop('BEGIN', 'VEVENT')
                 write_prop('UID', uid)
-                write_date('DTSTAMP', localtime(milestone['due']))
+                write_utctime('DTSTAMP', localtime(milestone['due']))
                 write_date('DTSTART', localtime(milestone['due']))
                 write_prop('SUMMARY', 'Milestone %s' % milestone['name'])
                 write_prop('URL', req.base_url + '/milestone/' +
@@ -339,12 +339,14 @@ class MilestoneModule(Component):
             return True
 
     def process_request(self, req):
+        milestone_id = req.args.get('id')
+            
         req.perm.assert_permission('MILESTONE_VIEW')
 
         add_link(req, 'up', req.href.roadmap(), 'Roadmap')
 
         db = self.env.get_db_cnx()
-        milestone = Milestone(self.env, req.args.get('id'), db)
+        milestone = Milestone(self.env, milestone_id, db)
         action = req.args.get('action', 'view')
 
         if req.method == 'POST':
@@ -364,6 +366,9 @@ class MilestoneModule(Component):
         else:
             self._render_view(req, db, milestone)
 
+        if not milestone_id and action != 'new':
+            req.redirect(req.href.roadmap())
+
         add_stylesheet(req, 'common/css/roadmap.css')
         return 'milestone.cs', None
 
